pyparsing.pyparsing.Or

Package pyparsing :: Module pyparsing :: Class Or |
[frames | no frames]

## Type Or

       object --+
                |
    ParserElement --+
                    |
      ParseExpression --+
                        |
                       Or

Requires that at least one ParseExpression is found. If two expressions match, the expression that matches the longest string will be used. May be constructed using the '^' operator.

Method Summary
| `__init__(self, exprs, savelist)`
| `__ixor__(self, other)`
| `__str__(self)`
| `checkRecursion(self, parseElementList)`
| `parseImpl(self, instring, loc, doActions)`
Inherited from `ParseExpression`: `__getitem__`, `append`, `ignore`, `leaveWhitespace`, `setResultsName`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `getException`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net